@@ -65,10 +65,15 @@ Cantor::Session* RBackend::createSession()
 Cantor::Backend::Capabilities RBackend::capabilities() const
 {
     qDebug()<<"Requesting capabilities of RSession";
-    return  Cantor::Backend::InteractiveMode |
-            Cantor::Backend::SyntaxHighlighting |
-            Cantor::Backend::Completion |
-            Cantor::Backend::VariableManagement;
+    Cantor::Backend::Capabilities cap=
+        SyntaxHighlighting|
+        Completion |
+        InteractiveMode;
+
+    if (RServerSettings::variableManagement())
+        cap |= VariableManagement;
+
+    return cap;
 }
 
 bool RBackend::requirementsFullfilled() const
@@ -89,6 +94,10 @@ KConfigSkeleton* RBackend::config() const
 
 QUrl RBackend::helpUrl() const
 {
+    const QUrl& localDoc = RServerSettings::self()->localDoc();
+    if (!localDoc.isEmpty())
+        return localDoc;
+    else
     return QUrl(i18nc("the url to the documentation of R, please check if there is a translated version and use the correct url",
                  "http://rwiki.sciviews.org/doku.php?id=rdoc:rdoc"));
 }
