@@ -21,6 +21,7 @@
 
 #include "rhighlighter.h"
 #include "rkeywords.h"
+#include "rsession.h"
 
 #include <QTextEdit>
 #include <QDebug>
@@ -32,7 +33,7 @@ const QStringList RHighlighter::operators_list=QStringList()
 const QStringList RHighlighter::specials_list=QStringList()
     << QLatin1String("BUG") << QLatin1String("TODO") << QLatin1String("FIXME") << QLatin1String("NB") << QLatin1String("WARNING") << QLatin1String("ERROR");
 
-RHighlighter::RHighlighter(QObject* parent) : Cantor::DefaultHighlighter(parent)
+RHighlighter::RHighlighter(QObject* parent, RSession* session) : Cantor::DefaultHighlighter(parent, session)
 {
     addKeywords(RKeywords::instance()->keywords());
 
@@ -42,11 +43,6 @@ RHighlighter::RHighlighter(QObject* parent) : Cantor::DefaultHighlighter(parent)
         specials.append(QRegExp(QLatin1String("\\b")+s+QLatin1String("\\b")));
 }
 
-void RHighlighter::refreshSyntaxRegExps()
-{
-    emit syntaxRegExps(variables,functions);
-}
-
 // FIXME: due to lack of lookbehinds in QRegExp here we use a flag showing if we need to shift the boundary of formatting
 // to make up for the accidentally matched character
 void RHighlighter::formatRule(const QRegExp &p, const QTextCharFormat &fmt, const QString& text,bool shift)
@@ -85,8 +81,3 @@ void RHighlighter::highlightBlock(const QString& text)
     massFormat(variables,variableFormat(),text);
     formatRule(QRegExp(QLatin1String("\"[^\"]+\"")),stringFormat(),text); // WARNING a bit redundant
 }
-
-void RHighlighter::updateHighlighting()
-{
-    emit rulesChanged();
-}
