@@ -55,8 +55,8 @@ void PythonCompletionObject::fetchCompletions()
         qDebug() << "run fetchCompletions";
         const QString& expr = QString::fromLatin1(
             "from __main__ import __dict__;"
-            "from rlcompleter import Completer;"
-            "print('|'.join(Completer(__dict__).global_matches('%1')+Completer(__dict__).attr_matches('%1')))"
+            "import rlcompleter;"
+            "print('|'.join(rlcompleter.Completer(__dict__).global_matches('%1')+rlcompleter.Completer(__dict__).attr_matches('%1')))"
         ).arg(command());
         m_expression = session()->evaluateExpression(expr, Cantor::Expression::FinishingBehavior::DoNotDelete, true);
         // TODO: Python exec the expression before connect, so manualy run handler. Uncomment the connection after removing DBus
@@ -112,7 +112,7 @@ void PythonCompletionObject::extractCompletions(Cantor::Expression::Status statu
 
         case Cantor::Expression::Done:
             if (m_expression->result())
-                setCompletions(m_expression->result()->toHtml().remove(QLatin1Char('(')).split(QLatin1Char('|')));
+                setCompletions(m_expression->result()->data().toString().remove(QLatin1Char('(')).split(QLatin1Char('|')));
             break;
         default:
             return;
@@ -143,14 +143,13 @@ void PythonCompletionObject::extractIdentifierType(Cantor::Expression::Status st
         case Cantor::Expression::Done:
             if (m_expression->result())
             {
-                if (m_expression->result())
-                {
-                    if (m_expression->result()->toHtml() == QLatin1String("True"))
-                        emit fetchingTypeDone(FunctionType);
-                    else
-                        emit fetchingTypeDone(VariableType);
-                }
+                if (m_expression->result()->data().toString() == QLatin1String("True"))
+                    emit fetchingTypeDone(FunctionType);
+                else
+                    emit fetchingTypeDone(VariableType);
             }
+            else
+                emit fetchingTypeDone(UnknownType);
             break;
         default:
             return;
